/***************************************************************************
                          serial.cpp  -  description
                             -------------------
    begin                : Fri Aug 9 2002
    copyright            : (C) 2002 by Michiel van Turnhout
    email                : info@qris.myweb.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "serial.h"

Serial::Serial(char * device, int baudrate){
  fd = openSerial(device,baudrate);
}

Serial::~Serial(){
  closeSerial(fd);
}

int Serial::openSerial(char *device,int baudrate) {
  int fd;

  fd = open(device, O_RDWR | O_NOCTTY );
  if (fd <0) {perror(device); return(-1); }

  tcgetattr(fd,&oldtio); /* save current port settings */

  bzero(&newtio, sizeof(newtio));
  newtio.c_cflag = baudrate | CRTSCTS | CS8 | CLOCAL | CREAD;
  newtio.c_iflag = IGNPAR;
  newtio.c_oflag = 0;

  /* set input mode (non-canonical, no echo,...) */
  newtio.c_lflag = 0;

  newtio.c_cc[VTIME]    = 0;   /* inter-character timer unused */
  newtio.c_cc[VMIN]     = 1;   /* blocking read until 5 chars received */

  tcflush(fd, TCIFLUSH);
  tcsetattr(fd,TCSANOW,&newtio);

  return(fd);
}

void Serial::closeSerial(int fd) {
  tcsetattr(fd,TCSANOW,&oldtio);
}

int Serial::serialRead(char * buffer,int size) {
  int rsize;
  rsize = read(fd,buffer,1);
  return rsize;
}

int Serial::serialWrite(char * buffer, int size) {
  int wsize;
  wsize = write(fd,buffer,12);
  return wsize;
}
