/***************************************************************************
                          serial.h  -  description
                             -------------------
    begin                : Fri Aug 9 2002
    copyright            : (C) 2002 by Michiel van Turnhout
    email                : info@qris.myweb.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SERIAL_H
#define SERIAL_H
/**
 * The base serial IO.
 *
 * This class can communicate with any serial device connected
 * The default baudrate is 9600 on device /dev/ttyS0
 *
 * @short Base serial IO
 * @author Michiel van Turnhout
 * @version 0.1alpha
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <termios.h>
#include <stdio.h>
#include <unistd.h>
#include <string.h>

#define DEF_BAUDRATE B9600
#define DEF_SERIAL_PORT "/dev/ttyS0"
#define _POSIX_SOURCE 1 /* POSIX compliant source */

class Serial {
private:
  struct termios oldtio,newtio;
  int fd;
  int openSerial(char *,int);
/**
*Docu on closeSerial
*@param filediscriptor of the open device
*@return none
*/
  void closeSerial(int );
public:
/**
*Contructor for a serial communication object
*The Constructor has default parametervalues
*@param device name of the serial port
*@param baudrate to commnicate with
*@return none
*/
	Serial(char * device=DEF_SERIAL_PORT,int baudrate=DEF_BAUDRATE);
	~Serial();
/**
*Read from serial port
*@param buffer pointer
*@param size in number of bytes to read
*@return number of bytes read
*/
  int serialRead(char *,int );
/**
*Write to serial port
*@param buffer pointer
*@param size in number of bytes to write
*@return number of actualy bytes written
*/
  int serialWrite(char *,int );
};

#endif
