/***************************************************************************
                          serial.cpp  -  description
                             -------------------
    begin                : Wed Aug 7 2002
    copyright            : (C) 2002 by Michiel van Turnhout
    email                : info@qris.myweb.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "speedo.h"

Speedo::Speedo(){
  serial = new Serial(SERIAL_PORT,SPEEDO_BAUDRATE);
  speedo_prescaler = SPEEDO_PRESCALER;
  speedo_clock = SPEEDO_CLOCK;
  whsz = SPEEDO_WHSZ;
  speed = 2;
	wheelrounds = 0;
}

Speedo::~Speedo(){
  delete serial;
}

void Speedo::setSpeed(int nspeed) {
  speed = nspeed;
}

bool Speedo::isRunning(void) {
  return running;
}

void Speedo::setRunning(bool status) {
  stop = status;
}

void Speedo::setWheelsize(int size) {
  whsz = size;
}

void Speedo::setSpeedoClock(double clock) {
  speedo_clock = clock;
}

// this is the function that is run by the thread
void Speedo::run() {
  int res;
  char buf[255];
  double timertic;

  int incval = 1;
	int speedo = 0;
	char spd[] = "0000";
	char whr[] = "00000000";


  //calculate the tic update rate for timer1 in the AVR mcu
  timertic = (double) speedo_prescaler / speedo_clock;

  //initialize the thread controll parameters
  running = true;
  stop = false;

  while (running) {       /* loop for input */
		wheelrounds+=incval;
    incval=speed/4;     // the number of wheelrounds varies with the speed
    //calculate from speed to timer 1 capture value
    //var1 = (double) speed * 27.7778;
    speedo = (int) (((double) whsz / ((double) speed * 27.7778)) / timertic);

    res = serial->serialRead(buf,1); /* returns after 1 char have been input */
    buf[res]=0;
    //printf(":%s:%d\n", buf, res);
		if (buf[0]=='g') {
      //get received now send the speed and the wheelrounds
			sprintf(spd,"%04x",speedo);
			sprintf(whr,"%08x",wheelrounds);
			sprintf(buf,"%s%s",spd,whr);
			serial->serialWrite(buf,12);  //write(fd,buf,12);
      //printf("speed %d capture %04x\n",speed,speedo);
		} else
      if (buf[0]=='r') {
        //reset received
        wheelrounds = 0;
      }
    //check if thread should stop
    if(stop) running = false;
	}
}

