/***************************************************************************
                          serial.h  -  description
                             -------------------
    begin                : Wed Aug 7 2002
    copyright            : (C) 2002 by Michiel van Turnhout
    email                : info@qris.myweb.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPEEDO_H
#define SPEEDO_H

/**
 * Communication thread for pabilotest.
 *
 * Because the main thread is doing all the GUI work
 * and serial IO may occur at any time. We use a separate thread to do
 * all communication with the PabiloII Palm application.
 * When a request comes in this thread answers it with the current known values.
 * @short Communication thread class
 * @author Michiel van Turnhout
 * @version 0.1alpha
 */

#include <qthread.h>
#include <qwidget.h>

#include "serial.h"

#define SERIAL_PORT "/dev/ttyS0"
#define SPEEDO_BAUDRATE B115200
#define SPEEDO_PRESCALER 1024
#define SPEEDO_CLOCK 11059200
#define SPEEDO_WHSZ 214

class Speedo : public QThread  {
private:
  Serial *serial;
  bool running,stop;
  int whsz,speed,wheelrounds;
  double speedo_prescaler, speedo_clock;
  void setSpeedoClock(double);
public:
	Speedo();
	~Speedo();
/**
*Check if the thread is currently running
*@return running A boolean value indicating if the thread is running.
*/
  bool isRunning(void);
/**
*Set the speed property of this class.
*
*The speed property is send to the PabiloII application
*@param speed The current speed to send to the Palm device over serial
*/
  void setSpeed(int);
/**
*Set a property to stop this thread running.
*
*Because we can not just stop the thread. We use this property to indicate
* that the run function should end.
*@param running a boolean value indicating wether the thread should continue or stop running.
*/
  void setRunning(bool);
/**
*Set the wheelsize property.
*
*The wheelsize property is used to calculate the right value to send to the PabiloII application.
*@param wheelsize The new wheelsize value
*/
  void setWheelsize(int);
protected:
/**
*The actual routine that is run by the thread.
*
*It calculates the vaues to send to the PabiloII application and sends the using the Serial class
*@see Serial
*/
  void run();
};

#endif
